@@ -1,4 +1,16 @@
 # (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
+
 # stdlib
 
 import logging
@@ -110,6 +122,8 @@ class Apache(checks.AgentCheck):
                 self.log.warn("Assuming url was not correct. Trying to add ?auto suffix to the url")
                 self.check(instance)
             else:
-                return services_checks.Status.DOWN, "%s is DOWN, error: No metrics available.".format(service_check_name)
+                return services_checks.Status.DOWN,
+                "%s is DOWN, error: No metrics available.".format(service_check_name)
         else:
-            log.debug("Collected {0} metrics for {1} Apache Web Server".format(apache_host, metric_count))
+            log.debug("Collected {0} metrics for {1} Apache Web Server".format(apache_host,
+                                                                               metric_count))
