@@ -1,4 +1,15 @@
 # (C) Copyright 2015,2016 Hewlett Packard Enterprise Development Company LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 import json
 import socket
@@ -22,35 +33,55 @@ class ElasticSearch(AgentCheck):
         "elasticsearch.docs.deleted": ("gauge", "indices.docs.deleted"),
         "elasticsearch.store.size": ("gauge", "indices.store.size_in_bytes"),
         "elasticsearch.indexing.index.total": ("gauge", "indices.indexing.index_total"),
-        "elasticsearch.indexing.index.time": ("gauge", "indices.indexing.index_time_in_millis", lambda v: float(v) / 1000),
+        "elasticsearch.indexing.index.time": ("gauge",
+                                              "indices.indexing.index_time_in_millis",
+                                              lambda v: float(v) / 1000),
         "elasticsearch.indexing.index.current": ("gauge", "indices.indexing.index_current"),
         "elasticsearch.indexing.delete.total": ("gauge", "indices.indexing.delete_total"),
-        "elasticsearch.indexing.delete.time": ("gauge", "indices.indexing.delete_time_in_millis", lambda v: float(v) / 1000),
+        "elasticsearch.indexing.delete.time": ("gauge",
+                                               "indices.indexing.delete_time_in_millis",
+                                               lambda v: float(v) / 1000),
         "elasticsearch.indexing.delete.current": ("gauge", "indices.indexing.delete_current"),
         "elasticsearch.get.total": ("gauge", "indices.get.total"),
-        "elasticsearch.get.time": ("gauge", "indices.get.time_in_millis", lambda v: float(v) / 1000),
+        "elasticsearch.get.time": ("gauge",
+                                   "indices.get.time_in_millis",
+                                   lambda v: float(v) / 1000),
         "elasticsearch.get.current": ("gauge", "indices.get.current"),
         "elasticsearch.get.exists.total": ("gauge", "indices.get.exists_total"),
-        "elasticsearch.get.exists.time": ("gauge", "indices.get.exists_time_in_millis", lambda v: float(v) / 1000),
+        "elasticsearch.get.exists.time": ("gauge",
+                                          "indices.get.exists_time_in_millis",
+                                          lambda v: float(v) / 1000),
         "elasticsearch.get.missing.total": ("gauge", "indices.get.missing_total"),
-        "elasticsearch.get.missing.time": ("gauge", "indices.get.missing_time_in_millis", lambda v: float(v) / 1000),
+        "elasticsearch.get.missing.time": ("gauge",
+                                           "indices.get.missing_time_in_millis",
+                                           lambda v: float(v) / 1000),
         "elasticsearch.search.query.total": ("gauge", "indices.search.query_total"),
-        "elasticsearch.search.query.time": ("gauge", "indices.search.query_time_in_millis", lambda v: float(v) / 1000),
+        "elasticsearch.search.query.time": ("gauge",
+                                            "indices.search.query_time_in_millis",
+                                            lambda v: float(v) / 1000),
         "elasticsearch.search.query.current": ("gauge", "indices.search.query_current"),
         "elasticsearch.search.fetch.total": ("gauge", "indices.search.fetch_total"),
-        "elasticsearch.search.fetch.time": ("gauge", "indices.search.fetch_time_in_millis", lambda v: float(v) / 1000),
+        "elasticsearch.search.fetch.time": ("gauge",
+                                            "indices.search.fetch_time_in_millis",
+                                            lambda v: float(v) / 1000),
         "elasticsearch.search.fetch.current": ("gauge", "indices.search.fetch_current"),
         "elasticsearch.merges.current": ("gauge", "indices.merges.current"),
         "elasticsearch.merges.current.docs": ("gauge", "indices.merges.current_docs"),
         "elasticsearch.merges.current.size": ("gauge", "indices.merges.current_size_in_bytes"),
         "elasticsearch.merges.total": ("gauge", "indices.merges.total"),
-        "elasticsearch.merges.total.time": ("gauge", "indices.merges.total_time_in_millis", lambda v: float(v) / 1000),
+        "elasticsearch.merges.total.time": ("gauge",
+                                            "indices.merges.total_time_in_millis",
+                                            lambda v: float(v) / 1000),
         "elasticsearch.merges.total.docs": ("gauge", "indices.merges.total_docs"),
         "elasticsearch.merges.total.size": ("gauge", "indices.merges.total_size_in_bytes"),
         "elasticsearch.refresh.total": ("gauge", "indices.refresh.total"),
-        "elasticsearch.refresh.total.time": ("gauge", "indices.refresh.total_time_in_millis", lambda v: float(v) / 1000),
+        "elasticsearch.refresh.total.time": ("gauge",
+                                             "indices.refresh.total_time_in_millis",
+                                             lambda v: float(v) / 1000),
         "elasticsearch.flush.total": ("gauge", "indices.flush.total"),
-        "elasticsearch.flush.total.time": ("gauge", "indices.flush.total_time_in_millis", lambda v: float(v) / 1000),
+        "elasticsearch.flush.total.time": ("gauge",
+                                           "indices.flush.total_time_in_millis",
+                                           lambda v: float(v) / 1000),
         "elasticsearch.process.open_fd": ("gauge", "process.open_file_descriptors"),
         "elasticsearch.transport.rx_count": ("gauge", "transport.rx_count"),
         "elasticsearch.transport.tx_count": ("gauge", "transport.tx_count"),
@@ -78,9 +109,11 @@ class ElasticSearch(AgentCheck):
         "elasticsearch.thread_pool.index.queue": ("gauge", "thread_pool.index.queue"),
         "elasticsearch.thread_pool.index.rejected": ("gauge", "thread_pool.index.rejected"),
         "elasticsearch.thread_pool.management.active": ("gauge", "thread_pool.management.active"),
-        "elasticsearch.thread_pool.management.threads": ("gauge", "thread_pool.management.threads"),
+        "elasticsearch.thread_pool.management.threads": ("gauge",
+                                                         "thread_pool.management.threads"),
         "elasticsearch.thread_pool.management.queue": ("gauge", "thread_pool.management.queue"),
-        "elasticsearch.thread_pool.management.rejected": ("gauge", "thread_pool.management.rejected"),
+        "elasticsearch.thread_pool.management.rejected": ("gauge",
+                                                          "thread_pool.management.rejected"),
         "elasticsearch.thread_pool.merge.active": ("gauge", "thread_pool.merge.active"),
         "elasticsearch.thread_pool.merge.threads": ("gauge", "thread_pool.merge.threads"),
         "elasticsearch.thread_pool.merge.queue": ("gauge", "thread_pool.merge.queue"),
@@ -88,7 +121,8 @@ class ElasticSearch(AgentCheck):
         "elasticsearch.thread_pool.percolate.active": ("gauge", "thread_pool.percolate.active"),
         "elasticsearch.thread_pool.percolate.threads": ("gauge", "thread_pool.percolate.threads"),
         "elasticsearch.thread_pool.percolate.queue": ("gauge", "thread_pool.percolate.queue"),
-        "elasticsearch.thread_pool.percolate.rejected": ("gauge", "thread_pool.percolate.rejected"),
+        "elasticsearch.thread_pool.percolate.rejected": ("gauge",
+                                                         "thread_pool.percolate.rejected"),
         "elasticsearch.thread_pool.refresh.active": ("gauge", "thread_pool.refresh.active"),
         "elasticsearch.thread_pool.refresh.threads": ("gauge", "thread_pool.refresh.threads"),
         "elasticsearch.thread_pool.refresh.queue": ("gauge", "thread_pool.refresh.queue"),
@@ -103,10 +137,16 @@ class ElasticSearch(AgentCheck):
         "elasticsearch.thread_pool.snapshot.rejected": ("gauge", "thread_pool.snapshot.rejected"),
         "elasticsearch.http.current_open": ("gauge", "http.current_open"),
         "elasticsearch.http.total_opened": ("gauge", "http.total_opened"),
-        "jvm.gc.concurrent_mark_sweep.count": ("gauge", "jvm.gc.collectors.ConcurrentMarkSweep.collection_count"),
-        "jvm.gc.concurrent_mark_sweep.collection_time": ("gauge", "jvm.gc.collectors.ConcurrentMarkSweep.collection_time_in_millis", lambda v: float(v) / 1000),
+        "jvm.gc.concurrent_mark_sweep.count": ("gauge", "jvm.gc.collectors.ConcurrentMarkSweep."
+                                               "collection_count"),
+        "jvm.gc.concurrent_mark_sweep.collection_time": ("gauge", "jvm.gc.collectors."
+                                                         "ConcurrentMarkSweep."
+                                                         "collection_time_in_millis",
+                                                         lambda v: float(v) / 1000),
         "jvm.gc.par_new.count": ("gauge", "jvm.gc.collectors.ParNew.collection_count"),
-        "jvm.gc.par_new.collection_time": ("gauge", "jvm.gc.collectors.ParNew.collection_time_in_millis", lambda v: float(v) / 1000),
+        "jvm.gc.par_new.collection_time": ("gauge", "jvm.gc.collectors.ParNew."
+                                           "collection_time_in_millis",
+                                           lambda v: float(v) / 1000),
         "jvm.mem.heap_committed": ("gauge", "jvm.mem.heap_committed_in_bytes"),
         "jvm.mem.heap_used": ("gauge", "jvm.mem.heap_used_in_bytes"),
         "jvm.mem.non_heap_committed": ("gauge", "jvm.mem.non_heap_committed_in_bytes"),
@@ -120,7 +160,10 @@ class ElasticSearch(AgentCheck):
         "elasticsearch.relocating_shards": ("gauge", "relocating_shards"),
         "elasticsearch.initializing_shards": ("gauge", "initializing_shards"),
         "elasticsearch.unassigned_shards": ("gauge", "unassigned_shards"),
-        "elasticsearch.cluster_status": ("gauge", "status", lambda v: {"red": 0, "yellow": 1, "green": 2}.get(v, -1)),
+        "elasticsearch.cluster_status": ("gauge", "status", lambda v:
+                                         {"red": 0,
+                                          "yellow": 1,
+                                          "green": 2}.get(v, -1)),
     }
 
     def __init__(self, name, init_config, agent_config):
@@ -193,11 +236,15 @@ class ElasticSearch(AgentCheck):
             self.NODES_URL = "/_nodes?network=true"
 
             additional_metrics = {
-                "elasticsearch.search.fetch.open_contexts": ("gauge", "indices.search.open_contexts"),
-                "elasticsearch.cache.filter.evictions": ("gauge", "indices.filter_cache.evictions"),
-                "elasticsearch.cache.filter.size": ("gauge", "indices.filter_cache.memory_size_in_bytes"),
+                "elasticsearch.search.fetch.open_contexts": ("gauge",
+                                                             "indices.search.open_contexts"),
+                "elasticsearch.cache.filter.evictions": ("gauge",
+                                                         "indices.filter_cache.evictions"),
+                "elasticsearch.cache.filter.size": ("gauge",
+                                                    "indices.filter_cache.memory_size_in_bytes"),
                 "elasticsearch.id_cache.size": ("gauge", "indices.id_cache.memory_size_in_bytes"),
-                "elasticsearch.fielddata.size": ("gauge", "indices.fielddata.memory_size_in_bytes"),
+                "elasticsearch.fielddata.size": ("gauge",
+                                                 "indices.fielddata.memory_size_in_bytes"),
                 "elasticsearch.fielddata.evictions": ("gauge", "indices.fielddata.evictions")
             }
 
@@ -218,9 +265,14 @@ class ElasticSearch(AgentCheck):
                 "elasticsearch.thread_pool.cache.queue": ("gauge", "thread_pool.cache.queue"),
                 "elasticsearch.thread_pool.cache.rejected": ("gauge", "thread_pool.cache.rejected"),
                 "jvm.gc.collection_count": ("gauge", "jvm.gc.collection_count"),
-                "jvm.gc.collection_time": ("gauge", "jvm.gc.collection_time_in_millis", lambda v: float(v) / 1000),
+                "jvm.gc.collection_time": ("gauge",
+                                           "jvm.gc.collection_time_in_millis",
+                                           lambda v: float(v) / 1000),
                 "jvm.gc.copy.count": ("gauge", "jvm.gc.collectors.Copy.collection_count"),
-                "jvm.gc.copy.collection_time": ("gauge", "jvm.gc.collectors.Copy.collection_time_in_millis", lambda v: float(v) / 1000)
+                "jvm.gc.copy.collection_time": ("gauge",
+                                                "jvm.gc.collectors."
+                                                "Copy.collection_time_in_millis",
+                                                lambda v: float(v) / 1000)
             }
 
         self.METRICS.update(additional_metrics)
