@@ -31,8 +31,9 @@ import traceback
 import uuid
 
 import logging
-
+import logging.handlers
 from numbers import Number
+from six import integer_types
 
 log = logging.getLogger(__name__)
 
@@ -43,7 +44,7 @@ VALID_HOSTNAME_RFC_1123_PATTERN = re.compile(
 MAX_HOSTNAME_LEN = 255
 LOGGING_MAX_BYTES = 5 * 1024 * 1024
 
-NumericTypes = (float, int, long)
+NumericTypes = (float,) + integer_types
 
 import monasca_agent.common.config as configuration
 from monasca_agent.common.exceptions import PathNotFound
@@ -601,8 +602,8 @@ def load_check_directory():
 
 def initialize_logging(logger_name):
     try:
-        log_format = '%%(asctime)s | %%(levelname)s | %s | %%(name)s(%%(filename)s:%%(lineno)s) '
-        '| %%(message)s' % logger_name
+        log_format = '%%(asctime)s | %%(levelname)s | %s | %%(name)s(%%(filename)s:%%(lineno)s) ' \
+            '| %%(message)s' % logger_name
         log_date_format = "%Y-%m-%d %H:%M:%S %Z"
         config = configuration.Config()
         logging_config = config.get_config(sections='Logging')
@@ -635,9 +636,8 @@ def initialize_logging(logger_name):
         # set up syslog
         if logging_config['log_to_syslog']:
             try:
-                syslog_format = '%s[%%(process)d]: %%(levelname)s (%%(filename)s:%%(lineno)s): '
-                '%%(message)s' % logger_name
-                from logging.handlers import SysLogHandler
+                syslog_format = '%s[%%(process)d]: %%(levelname)s (%%(filename)s:%%(lineno)s): ' \
+                    '%%(message)s' % logger_name
 
                 if logging_config['syslog_host'] is not None and logging_config[
                         'syslog_port'] is not None:
@@ -648,7 +648,8 @@ def initialize_logging(logger_name):
                     if sys.platform == 'darwin':
                         sys_log_addr = "/var/run/syslog"
 
-                handler = SysLogHandler(address=sys_log_addr, facility=SysLogHandler.LOG_DAEMON)
+                handler = logging.handlers.SysLogHandler(
+                    address=sys_log_addr, facility=logging.handlers.SysLogHandler.LOG_DAEMON)
                 handler.setFormatter(
                     logging.Formatter(syslog_format, log_date_format))
                 root_log = logging.getLogger()
