@@ -1,4 +1,6 @@
 # (C) Copyright 2015,2016 Hewlett Packard Enterprise Development Company LP
+# (C) Copyright 2018 SUSE LLC
+
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -13,7 +15,8 @@
 
 import logging
 import os
-import urllib2
+
+from six.moves import urllib
 
 import monasca_setup.agent_config
 import monasca_setup.detection
@@ -21,8 +24,12 @@ import monasca_setup.detection
 log = logging.getLogger(__name__)
 
 # Process name is apache2 on Debian derivatives, on RHEL derivatives it's httpd,
-# on openSUSE/SLES it might be httpd-prefork or httpd-worker
-APACHE_PROCESS_NAMES = ('apache2', 'httpd', 'httpd-prefork', 'httpd-worker')
+# on openSUSE/SLES it might be httpd-prefork or httpd-worker. With some versions
+# of apache2-mod_perl, e.g., 2.0.8, the process name is "/usr/sbin/httpd" after
+# being truncated to the UNIX limit of 15 characters. "/usr/sbin/httpd" should
+# be removed from the list when we conclude the offending verson(s) of the
+# mod_perl is no longer in use.
+APACHE_PROCESS_NAMES = ('apache2', 'httpd', 'httpd-prefork', 'httpd-worker', '/usr/sbin/httpd')
 DEFAULT_APACHE_CONFIG = '/root/.apache.cnf'
 CONFIG_ARG_KEYS = set(["url", "user", "password", "use_server_status_metrics"])
 
@@ -138,19 +145,19 @@ class Apache(monasca_setup.detection.Plugin):
                 return config
 
             if apache_user and apache_pass:
-                password_mgr = urllib2.HTTPPasswordMgrWithDefaultRealm()
+                password_mgr = urllib.HTTPPasswordMgrWithDefaultRealm()
                 password_mgr.add_password(None,
                                           apache_url,
                                           apache_user,
                                           apache_pass)
-                handler = urllib2.HTTPBasicAuthHandler(password_mgr)
+                handler = urllib.HTTPBasicAuthHandler(password_mgr)
             else:
                 if 'https' in apache_url:
-                    handler = urllib2.HTTPSHandler()
+                    handler = urllib.HTTPSHandler()
                 else:
-                    handler = urllib2.HTTPHandler()
+                    handler = urllib.HTTPHandler()
 
-            opener = urllib2.build_opener(handler)
+            opener = urllib.build_opener(handler)
 
             try:
                 request = opener.open(apache_url)
@@ -165,7 +172,7 @@ class Apache(monasca_setup.detection.Plugin):
                     log.info("\tSuccessfully setup Apache plugin.")
                 else:
                     log.warn('Unable to access the Apache server-status URL;' + error_msg)
-            except urllib2.URLError as e:
+            except urllib.URLError as e:
                 exception_msg = (
                     '\tError {0} received when accessing url {1}.'.format(e.reason, apache_url) +
                     '\n\tPlease ensure the Apache web server is running and your configuration ' +
